@@ -1,5 +1,5 @@
 """
-    Homonim: Radiometric homogenisation of aerial and satellite imagery
+    Homonim: Correction of aerial and satellite imagery to surface reflectance
     Copyright (C) 2021 Dugal Harris
     Email: dugalh@gmail.com
 
@@ -19,15 +19,31 @@
 from enum import Enum
 
 
-class Method(str, Enum):
-    """Enumeration for the homogenisation method"""
+class Model(str, Enum):
+    """ Surface reflectance correction model. """
     gain = 'gain'
+    """ 
+    Gain-only model, suitable for haze-free and zero offset images (i.e. images where a surface reflectance of 
+    zero corresponds to a pixel value of ~zero). 
+    """
     gain_blk_offset = 'gain-blk-offset'
+    """ 
+    Gain-only model applied to offset normalised image blocks.  Suitable for most source / reference combinations.
+    """
     gain_offset = 'gain-offset'
+    """
+    Gain and offset model.  The most accurate model, but sensitive to differences between source and reference, 
+    such as shadowing and land cover changes.  Suitable for well-matched source / reference image pairs.  
+    """
 
 
 class ProcCrs(str, Enum):
-    """Enumeration for the processing space (image co-ordinate system and resolution in which to perform processing)"""
+    """
+    CRS in which images will be processed.
+    """
     auto = 'auto'
+    """ Lowest resolution of the source and reference image CRS's (recommended). """
     src = 'src'
+    """ Source image CRS. """
     ref = 'ref'
+    """ Reference image CRS. """
